summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/Plugin.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/Plugin.java')
-rw-r--r--kdejava/koala/org/kde/koala/Plugin.java16
1 files changed, 8 insertions, 8 deletions
diff --git a/kdejava/koala/org/kde/koala/Plugin.java b/kdejava/koala/org/kde/koala/Plugin.java
index 349f4536..46529066 100644
--- a/kdejava/koala/org/kde/koala/Plugin.java
+++ b/kdejava/koala/org/kde/koala/Plugin.java
@@ -67,7 +67,7 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
to support enabling and disabling of plugins.
@short Load the plugin libraries from the directories appropriate to <code>instance</code> and make the Plugin objects children of <code>parent.</code>
*/
- public static native void loadPlugins(TQObject parent, KInstanceInterface instance);
+ public static native void loadPlugins(TQObject parent, TDEInstanceInterface instance);
/**
Load the plugin libraries specified by the list <code>docs</code> and make the
Plugin objects children of <code>parent</code> .
@@ -83,7 +83,7 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
to support enabling and disabling of plugins.
@short Load the plugin libraries specified by the list <code>pluginInfos</code>, make the Plugin objects children of <code>parent</code>, and use the given <code>instance.</code>
*/
// void loadPlugins(TQObject* arg1,const TQValueList<KParts::Plugin::PluginInfo>& arg2,const KInstance* arg3); >>>> NOT CONVERTED
/**
Load the plugin libraries for the given <code>instance</code>, make the
Plugin objects children of <code>parent</code>, and insert the plugin as a child GUI client
@@ -115,8 +115,8 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
</pre>
@short Load the plugin libraries for the given <code>instance</code>, make the Plugin objects children of <code>parent</code>, and insert the plugin as a child GUI client of <code>parentGUIClient.</code>
*/
- public static native void loadPlugins(TQObject parent, KXMLGUIClientInterface parentGUIClient, KInstanceInterface instance, boolean enableNewPluginsByDefault);
- public static native void loadPlugins(TQObject parent, KXMLGUIClientInterface parentGUIClient, KInstanceInterface instance);
+ public static native void loadPlugins(TQObject parent, KXMLGUIClientInterface parentGUIClient, TDEInstanceInterface instance, boolean enableNewPluginsByDefault);
+ public static native void loadPlugins(TQObject parent, KXMLGUIClientInterface parentGUIClient, TDEInstanceInterface instance);
/**
Returns a list of plugin objects loaded for <code>parent.</code> This
functions basically calls the queryList method of
@@ -125,14 +125,14 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
@short Returns a list of plugin objects loaded for <code>parent.</code>
*/
// TQPtrList<KParts::Plugin> pluginObjects(TQObject* arg1); >>>> NOT CONVERTED
- protected native void setInstance(KInstanceInterface instance);
+ protected native void setInstance(TDEInstanceInterface instance);
/**
Look for plugins in the <code>instance</code>'s "data" directory (+"/kpartplugins")
@return A list of TQDomDocument s, containing the parsed xml documents returned by plugins.
@short Look for plugins in the <code>instance</code>'s "data" directory (+"/kpartplugins")
*/
- // TQValueList<KParts::Plugin::PluginInfo> pluginInfos(const KInstance* arg1); >>>> NOT CONVERTED
+ // TQValueList<KParts::Plugin::PluginInfo> pluginInfos(const TDEInstance* arg1); >>>> NOT CONVERTED
/**
@return The plugin created from the library <code>libname</code>
@@ -165,11 +165,11 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
*/
public native KActionCollection actionCollection();
/**
- @return The instance ( KInstance ) for this GUI client.
+ @return The instance ( TDEInstance ) for this GUI client.
@short
*/
- public native KInstanceInterface instance();
+ public native TDEInstanceInterface instance();
/**
@return The parsed XML in a TQDomDocument, set by
setXMLFile() or setXML().
@@ -83,7 +83,7 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
*/
- // void loadPlugins(TQObject* arg1,const TQValueList<KParts::Plugin::PluginInfo>& arg2,const KInstance* arg3); >>>> NOT CONVERTED
+ // void loadPlugins(TQObject* arg1,const TQValueList<KParts::Plugin::PluginInfo>& arg2,const TDEInstance* arg3); >>>> NOT CONVERTED
/**
Load the plugin libraries for the given <code>instance</code>, make the